@@ -120,18 +120,22 @@ function (Ra, Rb, width = 12, Rf = 0, attribute = c("Beta", "Alpha", "R-Squared"
 
       main = paste("Rolling ",width,"-",freq.lab," ", attribute, sep="")
     }
-    chart.TimeSeries(Result.calc, main = main, ...)
+    if(hasArg("add")){
+      plot_object <- addSeries(Result.calc, main = main)
+    } else
+      plot_object <- chart.TimeSeries(Result.calc, main = main, ...)
+    return(plot_object)
 
 }
 
 ###############################################################################
 # R (http://r-project.org/) Econometrics for Performance and Risk Analysis
 #
-# Copyright (c) 2004-2014 Peter Carl and Brian G. Peterson
+# Copyright (c) 2004-2018 Peter Carl and Brian G. Peterson
 #
 # This R package is distributed under the terms of the GNU Public License (GPL)
 # for full details see the file COPYING
 #
-# $Id: chart.RollingRegression.R 3528 2014-09-11 12:43:17Z braverock $
+# $Id$
 #
 ###############################################################################
