@@ -33,13 +33,14 @@
 #' @seealso \code{\link{plot}}
 ###keywords ts multivariate distribution models hplot
 #' @examples
+#' \dontrun{
+#'   data(edhec)
+#'   chart.Scatter(edhec[,1],edhec[,2])
+#' }
 #' 
-#' data(edhec)
-#' chart.Scatter(edhec[,1],edhec[,2])
-#' 
-#' @export 
+#' @export
 chart.Scatter <-
-function (x, y, reference.grid = TRUE, main = "Title", ylab=NULL, xlab=NULL, xlim = NA, ylim = NA, colorset = 1, symbolset = 1, element.color = "darkgray", cex.axis = 0.8, cex.legend = 0.8, cex.lab = 1, cex.main = 1, ...)
+function (x, y, reference.grid = TRUE, main = "Title", ylab=NULL, xlab=NULL, xlim = NULL, ylim = NULL, colorset = 1, symbolset = 1, element.color = "darkgray", cex.axis = 0.8, cex.legend = 0.8, cex.lab = 1, cex.main = 1, ...)
 { # @author Peter Carl
 
     # DESCRIPTION:
@@ -67,7 +68,10 @@ function (x, y, reference.grid = TRUE, main = "Title", ylab=NULL, xlab=NULL, xli
     y = checkData(y, method = "vector")
 
     # pass in: cex.axis = cex.axis, cex.main = cex.main, cex.lab = cex.lab
-    plot(y~x, main = main, pch = symbolset, col=colorset, ...)
+    plot(y ~ x, main = main, pch = symbolset, col=colorset,
+         ylab = ylab, xlab = xlab, xlim = xlim, ylim = ylim,
+         ## cex.axis = cex.axis, cex.legend = cex.legend, cex.lab = cex.lab, cex.main = cex.main,
+         ...)
 
     if(reference.grid) {
         grid(col = element.color)
@@ -85,11 +89,11 @@ function (x, y, reference.grid = TRUE, main = "Title", ylab=NULL, xlab=NULL, xli
 ###############################################################################
 # R (http://r-project.org/) Econometrics for Performance and Risk Analysis
 #
-# Copyright (c) 2004-2014 Peter Carl and Brian G. Peterson
+# Copyright (c) 2004-2018 Peter Carl and Brian G. Peterson
 #
 # This R package is distributed under the terms of the GNU Public License (GPL)
 # for full details see the file COPYING
 #
-# $Id: chart.Scatter.R 3528 2014-09-11 12:43:17Z braverock $
+# $Id$
 #
 ###############################################################################
