@@ -1,5 +1,5 @@
 #' @rdname chart.TimeSeries
-#' @export 
+#' @export
 charts.TimeSeries <-
 function (R,  space = 0, main = "Returns", ...)
 { # @author Peter Carl
@@ -31,26 +31,14 @@ function (R,  space = 0, main = "Returns", ...)
     # mar: a numerical vector of the form c(bottom, left, top, right) which
     # gives the number of lines of margin to be specified on the four sides
     # of the plot. The default is c(5, 4, 4, 2) + 0.1
-    op <- par(oma = c(2,0,4,0), mar=c(0,4,0,4))
-    layout(matrix(c(1:columns), ncol = 1, byrow = TRUE), widths=1)
-    xaxis=FALSE
     yaxis=TRUE
-    for(i in 1:columns){
-         if(even(i))
-            yaxis.right=TRUE
-         else
-             yaxis.right=FALSE
-        if(i==columns)
-            xaxis = TRUE
-        chart.TimeSeries(R[,i,drop=FALSE],  xaxis=xaxis, main="", ylab=colnames(R)[i], ylim = c(ymin,ymax), yaxis=yaxis, yaxis.right=yaxis.right, ...)
-        if(i==1)
-            yaxis=FALSE
+    if(hasArg(space) || !isTRUE(space)) {
+      warning("The space argument of chart.TimeSeries has been deprecated, and may be removed in a future release, see help('chart.TimeSeries') for more information.")
     }
-
-    mtext(main,
-        side = 3, outer = TRUE, 
-        font = 2, cex = 1.2, line=1)
-    par(op)
+    chart.TimeSeries(R, multi.panel = TRUE, 
+                     main = main, 
+                     ylim = c(ymin, ymax), 
+                     yaxis = yaxis, ...)
     
 
 }
@@ -58,11 +46,11 @@ function (R,  space = 0, main = "Returns", ...)
 ###############################################################################
 # R (http://r-project.org/) Econometrics for Performance and Risk Analysis
 #
-# Copyright (c) 2004-2014 Peter Carl and Brian G. Peterson
+# Copyright (c) 2004-2018 Peter Carl and Brian G. Peterson
 #
 # This R package is distributed under the terms of the GNU Public License (GPL)
 # for full details see the file COPYING
 #
-# $Id: charts.TimeSeries.R 3301 2014-01-18 15:26:12Z braverock $
+# $Id$
 #
 ###############################################################################
\ No newline at end of file
