@@ -62,7 +62,7 @@ function (Ra, Rb, ...)
             merged.assets = merge(Ra[,column.a,drop=FALSE], Rb[,column.b,drop=FALSE])
             merged.assets = na.omit(merged.assets) # leaves the overlapping period
 
-            htest = cor.test(merged.assets[,1], merged.assets[,2], ...)
+            htest = cor.test(as.numeric(merged.assets[,1]), as.numeric(merged.assets[,2]), ...)
             values = cbind(htest$estimate, htest$p.value,htest$conf.int[1],htest$conf.int[2])
 
             if(column.a == 1 & column.b == 1) {
@@ -86,11 +86,11 @@ function (Ra, Rb, ...)
 ###############################################################################
 # R (http://r-project.org/) Econometrics for Performance and Risk Analysis
 #
-# Copyright (c) 2004-2014 Peter Carl and Brian G. Peterson
+# Copyright (c) 2004-2018 Peter Carl and Brian G. Peterson
 #
 # This R package is distributed under the terms of the GNU Public License (GPL)
 # for full details see the file COPYING
 #
-# $Id: table.Correlation.R 3528 2014-09-11 12:43:17Z braverock $
+# $Id$
 #
 ###############################################################################
